@@ -20,7 +20,7 @@ pub mod asynchronous;
 #[cfg(feature = "async")]
 pub use asynchronous::*;
 
-#[cfg(any(feature = "app", feature = "async"))]
+#[cfg(all(feature = "app", feature = "async"))]
 pub mod async_app;
-#[cfg(any(feature = "app", feature = "async"))]
+#[cfg(all(feature = "app", feature = "async"))]
 pub use async_app::*;
